
[![Documentation Status](https://readthedocs.org/projects/pyclay/badge/?version=latest)](https://pyclay.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/dataClay.png)](https://badge.fury.io/py/dataClay)

# dataClay Python codebase

This repository holds the `pyclay` Python package. This package is used both
by the dataClay Python clients and also for the dataClay service Execution
Environment.

## Installation

This package is available from PyPI, so just `pip` it:

    $ pip install dataClay

## Documentation

Official documentation available at [read the docs](https://pyclay.readthedocs.io/en/latest/)

## Other resources

[BSC official dataClay webpage](https://www.bsc.es/dataclay)

---

![dataClay logo](https://www.bsc.es/sites/default/files/public/styles/bscw2_-_simple_crop_style/public/bscw2/content/software-app/logo/logo_dataclay_web_bsc.jpg)
